ToastHandler class

Inheritance

Constructors

ToastHandler({ToastHandlerGravity gravity = ToastHandlerGravity.bottom, ToastHandlerLength length = ToastHandlerLength.long, Color backgroundColor = Colors.black87, Color textColor = Colors.white, double textSize = 12, String? customMessage, bool handleWhenRejected = false})

Properties

backgroundColor → Color
final
customMessage → String?
final
fToast ↔ FToast?
getter/setter pair
gravity → ToastHandlerGravity
final
handleWhenRejected → bool
final
hashCode → int
The hash code for this object.
no setterinherited
length → ToastHandlerLength
final
localizationOptions → LocalizationOptions
Get currently used localization options
no setterinherited
logger ↔ CatcherLogger
Logger instance
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color
final
textSize → double
final

Methods

getSupportedPlatforms() → List<PlatformType>
Get list of supported platforms
override
handle(Report report, BuildContext? context) → Future<bool>
Method called when report has been accepted by user
override
isContextRequired() → bool
Check if given report mode requires context to run
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLocalizationOptions(LocalizationOptions? localizationOptions) → void
Set localization options (translations) to this report mode
inherited
shouldHandleWhenRejected() → bool
Check whether report mode should auto confirm without user confirmation.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited